Struct GeneratorClient
pub struct GeneratorClient {
client: Client,
}Fields
client: ClientImplementations
impl GeneratorClient
impl GeneratorClient
pub fn password(
&self,
input: PasswordGeneratorRequest,
) -> Result<String, PasswordError>
pub fn password( &self, input: PasswordGeneratorRequest, ) -> Result<String, PasswordError>
Generates a random password.
The character sets and password length can be customized using the input parameter.
Examples
use bitwarden_core::Client;
use bitwarden_generators::{GeneratorClientsExt, PassphraseError, PasswordGeneratorRequest};
async fn test() -> Result<(), PassphraseError> {
let input = PasswordGeneratorRequest {
lowercase: true,
uppercase: true,
numbers: true,
length: 20,
..Default::default()
};
let password = Client::new(None).generator().password(input).unwrap();
println!("{}", password);
Ok(())
}pub fn password_rules(
&self,
rules: String,
) -> Result<PasswordGeneratorRequest, PasswordRulesError>
pub fn password_rules( &self, rules: String, ) -> Result<PasswordGeneratorRequest, PasswordRulesError>
Parses an HTML passwordrules attribute string into a [PasswordGeneratorRequest].
The returned request can be passed to GeneratorClient::password to produce a
password that satisfies the website’s declared constraints.
pub fn passphrase(
&self,
input: PassphraseGeneratorRequest,
) -> Result<String, PassphraseError>
pub fn passphrase( &self, input: PassphraseGeneratorRequest, ) -> Result<String, PassphraseError>
Generates a random passphrase.
A passphrase is a combination of random words separated by a character.
An example of passphrase is correct horse battery staple.
The number of words and their case, the word separator, and the inclusion of
a number in the passphrase can be customized using the input parameter.
Examples
use bitwarden_core::Client;
use bitwarden_generators::{GeneratorClientsExt, PassphraseError, PassphraseGeneratorRequest};
async fn test() -> Result<(), PassphraseError> {
let input = PassphraseGeneratorRequest {
num_words: 4,
..Default::default()
};
let passphrase = Client::new(None).generator().passphrase(input).unwrap();
println!("{}", passphrase);
Ok(())
}impl GeneratorClient
impl GeneratorClient
pub async fn username(
&self,
input: UsernameGeneratorRequest,
) -> Result<String, UsernameError>
pub async fn username( &self, input: UsernameGeneratorRequest, ) -> Result<String, UsernameError>
Generates a random username.
There are different username generation strategies, which can be customized using the
input parameter.
Note that most generation strategies will be executed on the client side, but Forwarded
will use third-party services, which may require a specific setup or API key.
use bitwarden_core::Client;
use bitwarden_generators::{GeneratorClientsExt, UsernameError, UsernameGeneratorRequest};
async fn test() -> Result<(), UsernameError> {
let input = UsernameGeneratorRequest::Word {
capitalize: true,
include_number: true,
};
let username = Client::new(None).generator().username(input).await.unwrap();
println!("{}", username);
Ok(())
}Trait Implementations
impl From<GeneratorClient> for JsValue
impl From<GeneratorClient> for JsValue
fn from(value: GeneratorClient) -> JsValue
fn from(value: GeneratorClient) -> JsValue
impl FromWasmAbi for GeneratorClient
impl FromWasmAbi for GeneratorClient
impl IntoWasmAbi for GeneratorClient
impl IntoWasmAbi for GeneratorClient
impl LongRefFromWasmAbi for GeneratorClient
impl LongRefFromWasmAbi for GeneratorClient
type Anchor = RcRef<GeneratorClient>
type Anchor = RcRef<GeneratorClient>
RefFromWasmAbi::Anchorunsafe fn long_ref_from_abi(
js: <GeneratorClient as LongRefFromWasmAbi>::Abi,
) -> <GeneratorClient as LongRefFromWasmAbi>::Anchor
unsafe fn long_ref_from_abi( js: <GeneratorClient as LongRefFromWasmAbi>::Abi, ) -> <GeneratorClient as LongRefFromWasmAbi>::Anchor
RefFromWasmAbi::ref_from_abiimpl OptionFromWasmAbi for GeneratorClient
impl OptionFromWasmAbi for GeneratorClient
fn is_none(abi: &<GeneratorClient as FromWasmAbi>::Abi) -> bool
fn is_none(abi: &<GeneratorClient as FromWasmAbi>::Abi) -> bool
None, and otherwise it will be passed to
FromWasmAbi.impl OptionIntoWasmAbi for GeneratorClient
impl OptionIntoWasmAbi for GeneratorClient
fn none() -> <GeneratorClient as IntoWasmAbi>::Abi
fn none() -> <GeneratorClient as IntoWasmAbi>::Abi
None branch of this option. Read moreimpl RefFromWasmAbi for GeneratorClient
impl RefFromWasmAbi for GeneratorClient
type Anchor = RcRef<GeneratorClient>
type Anchor = RcRef<GeneratorClient>
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.unsafe fn ref_from_abi(
js: <GeneratorClient as RefFromWasmAbi>::Abi,
) -> <GeneratorClient as RefFromWasmAbi>::Anchor
unsafe fn ref_from_abi( js: <GeneratorClient as RefFromWasmAbi>::Abi, ) -> <GeneratorClient as RefFromWasmAbi>::Anchor
impl RefMutFromWasmAbi for GeneratorClient
impl RefMutFromWasmAbi for GeneratorClient
type Anchor = RcRefMut<GeneratorClient>
type Anchor = RcRefMut<GeneratorClient>
RefFromWasmAbi::Anchorunsafe fn ref_mut_from_abi(
js: <GeneratorClient as RefMutFromWasmAbi>::Abi,
) -> <GeneratorClient as RefMutFromWasmAbi>::Anchor
unsafe fn ref_mut_from_abi( js: <GeneratorClient as RefMutFromWasmAbi>::Abi, ) -> <GeneratorClient as RefMutFromWasmAbi>::Anchor
RefFromWasmAbi::ref_from_abiimpl TryFromJsValue for GeneratorClient
impl TryFromJsValue for GeneratorClient
fn try_from_js_value(value: JsValue) -> Result<GeneratorClient, JsValue>
fn try_from_js_value(value: JsValue) -> Result<GeneratorClient, JsValue>
fn try_from_js_value_ref(value: &JsValue) -> Option<GeneratorClient>
fn try_from_js_value_ref(value: &JsValue) -> Option<GeneratorClient>
impl VectorFromWasmAbi for GeneratorClient
impl VectorFromWasmAbi for GeneratorClient
type Abi = <Box<[JsValue]> as FromWasmAbi>::Abi
unsafe fn vector_from_abi( js: <GeneratorClient as VectorFromWasmAbi>::Abi, ) -> Box<[GeneratorClient]>
impl VectorIntoWasmAbi for GeneratorClient
impl VectorIntoWasmAbi for GeneratorClient
type Abi = <Box<[JsValue]> as IntoWasmAbi>::Abi
fn vector_into_abi( vector: Box<[GeneratorClient]>, ) -> <GeneratorClient as VectorIntoWasmAbi>::Abi