Struct SendClient
pub struct SendClient {
pub(crate) client: Client,
}Fields
client: ClientImplementations
impl SendClient
impl SendClient
pub async fn access_send_v1(
&self,
send_id: String,
password: Option<String>,
) -> Result<SendAccessResponse, AccessSendError>
pub async fn access_send_v1( &self, send_id: String, password: Option<String>, ) -> Result<SendAccessResponse, AccessSendError>
Accesses a send using the V1 (legacy) API endpoint.
The password is the SHA256 hash of the user-entered password, if the send is
password-protected. The returned [SendAccessResponse] contains encrypted fields that must
be decrypted client-side using the key derived from the URL fragment.
pub async fn access_send(
&self,
access_token: String,
) -> Result<SendAccessResponse, AccessSendError>
pub async fn access_send( &self, access_token: String, ) -> Result<SendAccessResponse, AccessSendError>
Accesses a send using the V2 API endpoint, authenticated with a send access token. The returned [SendAccessResponse] contains encrypted fields that must be decrypted client-side using the key derived from the URL fragment.
pub async fn get_file_download_data_v1(
&self,
send_id: String,
file_id: String,
password: Option<String>,
) -> Result<SendFileDownloadData, GetFileDownloadDataError>
pub async fn get_file_download_data_v1( &self, send_id: String, file_id: String, password: Option<String>, ) -> Result<SendFileDownloadData, GetFileDownloadDataError>
Gets file download data for a file send using the V1 (legacy) API endpoint.
The password is the SHA256 hash of the user-entered password, if the send is
password-protected.
pub async fn get_file_download_data(
&self,
access_token: String,
file_id: String,
) -> Result<SendFileDownloadData, GetFileDownloadDataError>
pub async fn get_file_download_data( &self, access_token: String, file_id: String, ) -> Result<SendFileDownloadData, GetFileDownloadDataError>
Gets file download data for a file send using the V2 API endpoint, authenticated with a send access token.
impl SendClient
impl SendClient
pub fn decrypt(&self, send: Send) -> Result<SendView, SendDecryptError>
pub fn decrypt_list( &self, sends: Vec<Send>, ) -> Result<Vec<SendListView>, SendDecryptError>
pub fn decrypt_file( &self, send: Send, encrypted_file_path: &Path, decrypted_file_path: &Path, ) -> Result<(), SendDecryptFileError>
pub fn decrypt_buffer( &self, send: Send, encrypted_buffer: &[u8], ) -> Result<Vec<u8>, SendDecryptError>
pub fn encrypt(&self, send_view: SendView) -> Result<Send, SendEncryptError>
pub fn encrypt_file( &self, send: Send, decrypted_file_path: &Path, encrypted_file_path: &Path, ) -> Result<(), SendEncryptFileError>
pub fn encrypt_buffer( &self, send: Send, buffer: &[u8], ) -> Result<Vec<u8>, SendEncryptError>
impl SendClient
impl SendClient
impl SendClient
impl SendClient
pub async fn create_file_send(
&self,
request: SendAddRequest,
) -> Result<CreateFileSendResponse, CreateFileSendError>
pub async fn create_file_send( &self, request: SendAddRequest, ) -> Result<CreateFileSendResponse, CreateFileSendError>
Create a new file [Send] and save it to the server.
Returns the created send along with metadata needed to upload the file data.
After calling this, use SendClient::upload_send_file to upload the encrypted file.
pub async fn upload_send_file(
&self,
send_id: SendId,
file_id: String,
encrypted_file_name: String,
data: Vec<u8>,
) -> Result<(), UploadSendFileError>
pub async fn upload_send_file( &self, send_id: SendId, file_id: String, encrypted_file_name: String, data: Vec<u8>, ) -> Result<(), UploadSendFileError>
Upload the encrypted file data for a file [Send].
data must be the encrypted file content (encrypted with the send key).
encrypted_file_name is the encrypted file name string from [CreateFileSendResponse].
pub async fn renew_file_upload_url(
&self,
send_id: SendId,
file_id: String,
) -> Result<String, RenewFileUploadUrlError>
pub async fn renew_file_upload_url( &self, send_id: SendId, file_id: String, ) -> Result<String, RenewFileUploadUrlError>
Renew the upload URL for a file [Send].
Returns a fresh upload URL if the previous one has expired.
impl SendClient
impl SendClient
impl SendClient
impl SendClient
impl SendClient
impl SendClient
impl SendClient
impl SendClient
pub async fn remove_password(
&self,
send_id: SendId,
) -> Result<SendView, RemoveSendPasswordError>
pub async fn remove_password( &self, send_id: SendId, ) -> Result<SendView, RemoveSendPasswordError>
Remove the password from a [Send], saving the updated state to the server and local state.