SendClient

Struct SendClient 

pub struct SendClient {
    pub(crate) client: Client,
}

Fields

client: Client

Implementations



impl SendClient

pub fn decrypt(&self, send: Send) -> Result<SendView, SendDecryptError>

pub fn decrypt_list( &self, sends: Vec<Send>, ) -> Result<Vec<SendListView>, SendDecryptError>

pub fn decrypt_file( &self, send: Send, encrypted_file_path: &Path, decrypted_file_path: &Path, ) -> Result<(), SendDecryptFileError>

pub fn decrypt_buffer( &self, send: Send, encrypted_buffer: &[u8], ) -> Result<Vec<u8>, SendDecryptError>

pub fn encrypt(&self, send_view: SendView) -> Result<Send, SendEncryptError>

pub fn encrypt_file( &self, send: Send, decrypted_file_path: &Path, encrypted_file_path: &Path, ) -> Result<(), SendEncryptFileError>

pub fn encrypt_buffer( &self, send: Send, buffer: &[u8], ) -> Result<Vec<u8>, SendEncryptError>



impl SendClient

pub async fn create( &self, request: SendAddRequest, ) -> Result<SendView, CreateSendError>

Create a new [Send] and save it to the server.



impl SendClient

pub async fn edit( &self, send_id: SendId, request: SendEditRequest, ) -> Result<SendView, EditSendError>

Edit the [Send] and save it to the server.



impl SendClient

pub async fn list(&self) -> Result<Vec<SendView>, GetSendError>

Get all sends from state and decrypt them to a list of [SendView].

pub async fn get(&self, send_id: SendId) -> Result<SendView, GetSendError>

Get a specific [Send] by its ID from state and decrypt it to a [SendView].